'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const defaultUiConfig = require('./default-ui-config-8a058612.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const index$1 = require('./index-dbc5b08f.js');
const index$2 = require('./index-7a96dd15.js');
const string = require('./string-fd5038ca.js');
require('./default-language-4c779255.js');

const dyteMixedGridCss = ":host{display:block;height:100%;width:100%;font-family:var(--dyte-font-family, sans-serif);display:flex}main{display:flex;padding-left:var(--dyte-space-4, 16px);flex:6}main #switcher{margin-right:var(--dyte-space-4, 16px);box-sizing:border-box;display:flex;height:100%;width:var(--dyte-space-16, 64px);flex-direction:column}main #tabs{height:100%;flex:1 1 0%}.aside{width:66.666667%;max-width:400px;flex:6}.tab{display:flex;height:var(--dyte-space-16, 64px);width:var(--dyte-space-16, 64px);align-items:center;justify-content:center;margin-bottom:var(--dyte-space-2, 8px);font-size:12px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity))}.tab.active{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}.tab img{height:var(--dyte-space-7, 28px);width:var(--dyte-space-7, 28px);border-radius:var(--dyte-border-radius-sm, 4px)}@media (orientation: portrait){:host{flex-direction:column}:host .aside{width:100%;max-width:100%;flex:1 1 0%}:host main{height:50%;flex:none;flex-direction:column-reverse;padding-left:var(--dyte-space-4, 16px);padding-right:var(--dyte-space-4, 16px)}:host #switcher{margin-top:var(--dyte-space-4, 16px);height:var(--dyte-space-16, 64px);width:100%;flex-direction:row}:host #tabs{flex:1 1 0%}:host .tab{margin:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-2, 8px)}}:host([size='sm']){flex-direction:column}:host([size='sm']) .aside{width:100%;max-width:100%}:host([size='sm']) main{height:50%;flex:none;flex-direction:column-reverse;padding-left:var(--dyte-space-4, 16px);padding-right:var(--dyte-space-4, 16px)}:host([size='sm']) #switcher{margin-top:var(--dyte-space-4, 16px);height:var(--dyte-space-16, 64px);width:100%;flex-direction:row}:host([size='sm']) #tabs{flex:1 1 0%}:host([size='sm']) .tab{margin:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-2, 8px)}";

const DyteMixedGrid = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Participants */
    this.participants = [];
    /** Pinned Participants */
    this.pinnedParticipants = [];
    /** Screenshare Participants */
    this.screenShareParticipants = [];
    /** Active Plugins */
    this.plugins = [];
    /**
     * Aspect Ratio of participant tile
     *
     * Format: `width:height`
     */
    this.aspectRatio = '16:9';
    /** Gap between participant tiles */
    this.gap = 8;
    /** UI Config */
    this.config = defaultUiConfig.defaultConfig;
    /** Icon Pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
  }
  componentWillLoad() {
    // initialise states
    this.screenShareParticipantsChanged(this.screenShareParticipants);
    this.pluginsChanged(this.plugins);
  }
  screenShareParticipantsChanged(participants = []) {
    if (this.activeTab == null && participants.length > 0) {
      this.activeTab = { type: 'screenshare', participant: participants[0] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  pluginsChanged(plugins) {
    if (plugins.length > 0) {
      const lastIndex = plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: plugins[lastIndex] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  revalidateActiveTab() {
    if (this.activeTab != null) {
      if (this.activeTab.type === 'screenshare') {
        const { participant } = this.activeTab;
        if (!this.screenShareParticipants.some((p) => p.id === participant.id)) {
          this.reassignActiveTab();
        }
      }
      else {
        const { plugin } = this.activeTab;
        if (!this.plugins.some((p) => p.id === plugin.id)) {
          this.reassignActiveTab();
        }
      }
    }
  }
  reassignActiveTab() {
    if (this.screenShareParticipants.length > 0) {
      this.activeTab = { type: 'screenshare', participant: this.screenShareParticipants[0] };
    }
    else if (this.plugins.length > 0) {
      const lastIndex = this.plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: this.plugins[lastIndex] };
    }
  }
  shouldShowSwitcher() {
    return this.screenShareParticipants.length + this.plugins.length > 1;
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (index.h(index.Host, null, index.h("main", { id: "main-view", part: "main-view" }, this.shouldShowSwitcher() && (index.h("div", { id: "switcher", key: "switcher" }, this.screenShareParticipants.map((participant) => {
      var _a, _b, _c;
      const name = string.formatName(participant.name);
      return (index.h("dyte-button", { title: `${name}'s Screen Share`, key: participant.id, kind: "icon", class: {
          tab: true,
          active: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'screenshare' &&
            ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.participant.id) === participant.id,
        }, onClick: () => (this.activeTab = { type: 'screenshare', participant }) }, index.h("div", { class: "center" }, index.h("dyte-icon", { icon: this.iconPack.share_screen_person }), index.h("span", { class: "name" }, participant.id === ((_c = this.meeting) === null || _c === void 0 ? void 0 : _c.self.id)
        ? this.t('You')
        : string.shorten(name, 6)))));
    }), this.plugins.map((plugin) => {
      var _a, _b;
      return (index.h("dyte-button", { title: plugin.name, key: plugin.id, kind: "icon", class: {
          tab: true,
          active: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'plugin' && ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.plugin.id) === plugin.id,
        }, onClick: () => (this.activeTab = { type: 'plugin', plugin }) }, index.h("div", { class: "center" }, index.h("img", { src: plugin.picture }), index.h("span", { class: "name" }, string.shorten(plugin.name, 6)))));
    }))), index.h("div", { id: "tabs", key: "tabs" }, this.screenShareParticipants.map((participant) => {
      var _a, _b;
      return (index.h(index$2.Render, { element: "dyte-screenshare-view", defaults: defaults, props: {
          participant,
          key: participant.id,
          style: {
            display: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'screenshare' &&
              ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.participant.id) === participant.id
              ? 'flex'
              : 'none',
          },
        }, childProps: { participant, isScreenShare: true }, deepProps: true }));
    }), this.plugins.map((plugin) => {
      var _a, _b;
      return (index.h(index$2.Render, { element: "dyte-plugin-main", defaults: defaults, props: {
          plugin,
          key: plugin.id,
          style: {
            display: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'plugin' && ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.plugin.id) === plugin.id
              ? 'flex'
              : 'none',
          },
        } }));
    }))), index.h(index$2.Render, { element: "dyte-mixed-grid", defaults: defaults, childProps: {
        part: 'participants-grid',
        class: 'aside',
        participants: this.participants,
        pinnedParticipants: this.pinnedParticipants,
        screenShareParticipants: this.screenShareParticipants,
        plugins: this.plugins,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
        size: 'sm',
      }, onlyChildren: true })));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "screenShareParticipants": ["screenShareParticipantsChanged"],
    "plugins": ["pluginsChanged"]
  }; }
};
DyteMixedGrid.style = dyteMixedGridCss;

exports.dyte_mixed_grid = DyteMixedGrid;
