/* eslint-disable @stencil/strict-boolean-conditions */
import { Component, Host, h, Prop, State, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
/**
 * A component that lets you create a poll.
 */
export class DytePoll {
  constructor() {
    this.anonymous = false;
    this.hideVotes = true;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** Options */
    this.options = ['', ''];
  }
  removeOption(index) {
    var _a;
    this.options = this.options.filter((_, ind) => ind !== index);
    if (((_a = this.error) === null || _a === void 0 ? void 0 : _a.code) === 1)
      this.error = undefined;
  }
  addOption() {
    this.options = [...this.options, ''];
  }
  updateOption(ev, index) {
    var _a;
    this.options[index] = ev.target.value;
    if (((_a = this.error) === null || _a === void 0 ? void 0 : _a.code) === 1)
      this.error = undefined;
  }
  handleSubmit() {
    const pollObject = {
      question: this.question.value,
      options: this.options,
      anonymous: this.anonymous,
      hideVotes: this.hideVotes,
    };
    if (!pollObject.question) {
      this.error = {
        code: 0,
        message: this.t('Question is required.'),
      };
      return;
    }
    if (this.options.filter((op) => op.trim() === '').length > 0) {
      this.error = {
        code: 1,
        message: this.t('Empty options not allowed.'),
      };
      return;
    }
    this.onCreate.emit(pollObject);
  }
  render() {
    return (h(Host, null,
      h("div", { class: "create-poll" },
        h("p", null, this.t('Poll Question')),
        h("textarea", { onInput: () => {
            if (this.error && this.error.code === 0)
              this.error = undefined;
          }, ref: (e) => (this.question = e), placeholder: this.t('What is your poll for?') }),
        this.options.map((item, index) => (h("div", { class: "option" },
          h("input", { placeholder: this.t('Enter an option'), value: item, onInput: (event) => this.updateOption(event, index) }),
          index > 1 && (h("dyte-button", { kind: "icon", class: "auto remove-option", variant: "secondary", onClick: () => this.removeOption(index) },
            h("dyte-icon", { icon: this.iconPack.subtract })))))),
        h("dyte-button", { class: "add-option", variant: "secondary", onClick: () => this.addOption() }, this.t('Add an option')),
        h("label", null,
          h("input", { id: "anonymous", type: "checkbox", onChange: (e) => (this.anonymous = e.target.checked) }),
          this.t('Anonymous')),
        h("label", null,
          h("input", { id: "hideVotes", type: "checkbox", checked: true, onChange: (e) => (this.hideVotes = e.target.checked) }),
          this.t('Hide results before voting')),
        h("dyte-button", { kind: "wide", onClick: () => this.handleSubmit() }, this.t('Create Poll')),
        this.error && h("span", { class: "error-text" }, this.error.message))));
  }
  static get is() { return "dyte-poll-form"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-poll-form.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-poll-form.css"]
  }; }
  static get properties() { return {
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "options": {},
    "error": {}
  }; }
  static get events() { return [{
      "method": "onCreate",
      "name": "dyteCreatePoll",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event which is emitted when a poll is created"
      },
      "complexType": {
        "original": "PollObject",
        "resolved": "PollObject",
        "references": {
          "PollObject": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
}
