import { r as registerInstance, c as createEvent, h, H as Host } from './index-74ddb327.js';
import { d as defaultIconPack } from './default-icon-pack-eabba256.js';
import { u as useLanguage } from './index-a214afbc.js';
import { s as state } from './store-79928517.js';
import './default-language-04851639.js';

const dyteMicToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}:host(.audioDisabled) :slotted(dyte-icon){--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}";

const DyteMicToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    this.audioUpdateListener = ({ audioEnabled }) => {
      this.audioEnabled = audioEnabled;
    };
    this.mediaPermissionErrorListener = ({ kind, message }) => {
      if (kind === 'audio') {
        this.micPermission = message;
      }
    };
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.audioEnabled = false;
    this.canProduceAudio = false;
    this.micPermission = 'NOT_REQUESTED';
    this.toggleMic = () => {
      var _a;
      if (this.hasPermissionError()) {
        this.stateUpdate.emit({ activePermissionsMessage: true });
        state.activePermissionsMessage = true;
        return false;
      }
      const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
      if (self == null || !this.canProduceAudio) {
        return;
      }
      if (self.audioEnabled) {
        self.disableAudio();
      }
      else {
        self.enableAudio();
      }
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a, _b;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('audioUpdate', this.audioUpdateListener);
    (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.removeListener('mediaPermissionError', this.mediaPermissionErrorListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceAudio = self.permissions.produceAudio === 'ALLOWED';
      this.micPermission = meeting.self.mediaPermissions.audio || 'NOT_REQUESTED';
      this.audioEnabled = self.audioEnabled;
      self.addListener('audioUpdate', this.audioUpdateListener);
      self.addListener('mediaPermissionError', this.mediaPermissionErrorListener);
    }
  }
  hasPermissionError() {
    return this.micPermission !== 'NOT_REQUESTED' && this.micPermission !== 'ACCEPTED';
  }
  getState() {
    let tooltipLabel = '';
    let label = '';
    let icon = '';
    let classList = {};
    let hasError = this.hasPermissionError();
    if (this.audioEnabled && !hasError) {
      label = this.t('mic_on');
      icon = this.iconPack.mic_on;
    }
    else {
      label = this.t('mic_off');
      icon = this.iconPack.mic_off;
      classList['red-icon'] = true;
    }
    if (this.micPermission === 'COULD_NOT_START') {
      tooltipLabel = this.t('Unable to capture audio');
    }
    else if (this.micPermission === 'SYSTEM_DENIED') {
      tooltipLabel = this.t('perm_sys_denied');
    }
    else if (this.micPermission === 'DENIED') {
      tooltipLabel = this.t('perm_browser_denied');
    }
    else {
      tooltipLabel = this.audioEnabled ? this.t('Disable Mic') : this.t('Enable Mic');
    }
    return { tooltipLabel, label, icon, classList, showWarning: hasError };
  }
  render() {
    if (!this.canProduceAudio) {
      return null;
    }
    const { tooltipLabel, label, icon, classList, showWarning } = this.getState();
    return (h(Host, { title: label }, h("dyte-tooltip", { kind: "block", label: tooltipLabel, part: "tooltip" }, h("dyte-controlbar-button", { part: "controlbar-button", icon: icon, label: label, size: this.size, iconPack: this.iconPack, variant: this.variant, class: classList, onClick: this.toggleMic, showWarning: showWarning, disabled: showWarning }))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteMicToggle.style = dyteMicToggleCss;

export { DyteMicToggle as dyte_mic_toggle };
